.. _index:

StreamSets DataOps Platform SDK for Python
==========================================
|

The StreamSets DataOps Platform SDK for Python version 4.0.0 or greater enables users to interact with
StreamSets DataOps Platform programmatically using Python 3.4+.

.. tip::
   Looking for a different version of the SDK documentation? The documentation is also available for the `3.x <https://docs.streamsets.com/sdk/latest/index.html>`_ and `4.x <https://docs.streamsets.com/platform-sdk/4.x/index.html>`_
   versions.

.. toctree::
    :maxdepth: 3
    :hidden:

    learn
    set_up
    build
    run
    monitor
    manage
    advanced_search
    api
